.. currentmodule:: intake

#############
API reference
#############

This is a reference API class listing, and modules.

Top-level functions
===================

.. autosummary::
   :toctree: generated/

   open_stac_catalog
   open_stac_collection
   open_stac_item_collection
   open_stac_item

.. currentmodule:: intake_stac

Catalog Objects
===============

.. autosummary::
   :toctree: generated/

   StacCatalog
   StacCollection
   StacItemCollection
   StacItem
   catalog.StacEntry
